C+
C NAME:
C	Time2TwoThousand
C PURPOSE:
C	Convert from 2-element standard time relative to current origin to
C	times relative to 2000 Jan 1, 0 UT and v.v.
C CATEGORY:
C	gen/for/lib
C CALLING SEQUENCE:
	subroutine Time2TwoThousand(id,t,u)
C INPUTS:
C	id		integer		0  converts to times relative to 2000 Jan 1, 0 UT
C					1  converts from times relative to 2000 Jan 1, 0 UT
C	t(2)		integer		id=0: time relative to current origin
C					id=1: time relative to 2000 Jan 1, 0 UT
C OUTPUTS:
C	u(2)		integer		id=0: time relative to 2000 Jan 1, 0 UT
C					id=1: time relative to current origin
C CALLS:
C	Time2GetOrigin2000, Time2StandardOrigin
C PROCEDURE:
C MODIFICATION HISTORY:
C	JAN-2004, Paul Hick (UCSD/CASS; pphick@ucsd.edu)
C-
	    integer	id
	    integer	t(2)
	    integer	u(2)

	integer		t0(3)

	call Time2GetOrigin2000(t0)
	call Time2StandardOrigin(t0,id,t,u)

	return
C+
C NAME:
C	Time2JD
C PURPOSE:
C	Convert from 2-element standard time and Julian day and v.v.
C CATEGORY:
C	gen/for/lib
C CALLING SEQUENCE:
	entry Time2JD(id,t,u)
C INPUTS:
C	id		integer		0  converts time to Julian days
C					1  converts Julian days to time
C	t(2)		integer		id=0: time relative to current origin
C					id=1: time in Julian day
C OUTPUTS:
C	u(2)		integer		id=0: time in Julian day
C					id=1: time relative to current origin
C CALLS:
C	Time2GetOriginJD, Time2StandardOrigin
C PROCEDURE:
C MODIFICATION HISTORY:
C	JAN-2004, Paul Hick (UCSD/CASS; pphick@ucsd.edu)
C-
	call Time2GetOriginJD(t0)
	call Time2StandardOrigin(t0,id,t,u)

	return
C+
C NAME:
C	Time2MJD
C PURPOSE:
C	Convert from 2-element standard time to modified Julian day and v.v.
C CATEGORY:
C	gen/for/lib
C CALLING SEQUENCE:
	entry Time2MJD(id,t,u)
C INPUTS:
C	id		integer		0  converts time to modified Julian day
C					1  converts modified Julian day to time
C	t(2)		integer		id=0: time relative to current origin
C					id=1: time in modified Julian days
C OUTPUTS:
C	u(2)		integer		id=0: time in modified Julian days
C					id=1: time relative to current origin
C CALLS:
C	Time2GetOriginMJD, Time2StandardOrigin
C PROCEDURE:
C	The modified Julian day is defined as MJD = JD-2400000.5
C MODIFICATION HISTORY:
C	JAN-2004, Paul Hick (UCSD/CASS; pphick@ucsd.edu)
C-
	call Time2GetOriginMJD(t0)
	call Time2StandardOrigin(t0,id,t,u)

	return
	end
